@@ -13,6 +13,16 @@ double meanIT(NumericVector x, int t){
   return 1.0 * total / t;
 }
 
+// [[Rcpp::export]]
+double medianIT(NumericVector x, int t){
+  NumericVector y = x[Rcpp::Range(0, t)];
+  int size = y.size();
+  std::sort(y.begin(), y.begin()+t);
+  if (size % 2 != 0)
+    return (double)y[size/2];
+  return (double)(y[(size-1)/2] + y[size/2])/2.0;
+}
+
 // [[Rcpp::export]]
 double calc_amse(NumericMatrix IAX){
   const int nrw = IAX.nrow();
@@ -36,7 +46,7 @@ double calc_amse(NumericMatrix IAX){
     }
   }
   accmeasure = mean(amse);
-return accmeasure;
+  return accmeasure;
 }
 
 // [[Rcpp::export]]
@@ -102,47 +112,47 @@ double NaiveSV_Accry(NumericVector train_set, NumericVector frqx, int accry ){
   NumericVector ITsmape(n);
   NumericVector pe(n);
   deseas = train_set;
-      for(z = 0; z < p; z++){
-        fn = frqx[z] - 1;
-        for(j = 0; j < n; j++){
-          if(fn < j)
-            fitsn[j] = deseas[j - frqx[z]];
-          tfitsn[j] = tfitsn[j] + fitsn[j];
-        }
-        deseas = deseas - fitsn;
-      }
-    ITErr = train_set - tfitsn;
-    pe = (ITErr / tfitsn) * 100.0;
-    ITsmape = (abs(ITErr) / (abs(train_set) + abs(tfitsn))) * 200.0;
-    if ((accry==1) | (accry==2) | (accry==12) | (accry==13))
-      ITAcc = abs(ITErr);
-    else if ((accry==3) | (accry==4) | (accry==11) | (accry==15))
-      ITAcc = pow(ITErr, 2.0);
-    else if ((accry==5) | (accry==6) )
-      ITAcc = pe;
-    else if ((accry==7) | (accry==8) )
-      ITAcc = abs(pe);
-    else if ((accry==9) | (accry==10) )
-      ITAcc = ITsmape;
-    else
-      NumericVector ITAcc(n-1,NumericVector::get_na());
-    if ((accry==1) | (accry==3) | (accry==5) | (accry==7) | (accry==9) )
-      accmeasure = mean(ITAcc);
-    else if ((accry==2) | (accry==4) | (accry==6) | (accry==8) | (accry==10) )
-      accmeasure = median(ITAcc);
-    else if (accry==11)
-      accmeasure = sqrt(mean(ITAcc));
-    else if (accry==12)
-      accmeasure = 1.0;
-    else if (accry==13)
-      accmeasure = 1.0 * (mean(ITsmape) + mean(ITAcc)) / 2;
-    else if (accry==15)
-      accmeasure = ITAcc.size() * log(sum(ITAcc));
-    else if (accry==16)
-      accmeasure = var(ITErr);
-    else
-      accmeasure = NA_REAL;
-    return accmeasure;
+  for(z = 0; z < p; z++){
+    fn = frqx[z] - 1;
+    for(j = 0; j < n; j++){
+      if(fn < j)
+        fitsn[j] = deseas[j - frqx[z]];
+      tfitsn[j] = tfitsn[j] + fitsn[j];
+    }
+    deseas = deseas - fitsn;
+  }
+  ITErr = train_set - tfitsn;
+  pe = (ITErr / tfitsn) * 100.0;
+  ITsmape = (abs(ITErr) / (abs(train_set) + abs(tfitsn))) * 200.0;
+  if ((accry==1) | (accry==2) | (accry==12) | (accry==13))
+    ITAcc = abs(ITErr);
+  else if ((accry==3) | (accry==4) | (accry==11) | (accry==15))
+    ITAcc = pow(ITErr, 2.0);
+  else if ((accry==5) | (accry==6) )
+    ITAcc = pe;
+  else if ((accry==7) | (accry==8) )
+    ITAcc = abs(pe);
+  else if ((accry==9) | (accry==10) )
+    ITAcc = ITsmape;
+  else
+    NumericVector ITAcc(n-1,NumericVector::get_na());
+  if ((accry==1) | (accry==3) | (accry==5) | (accry==7) | (accry==9) )
+    accmeasure = mean(ITAcc);
+  else if ((accry==2) | (accry==4) | (accry==6) | (accry==8) | (accry==10) )
+    accmeasure = median(ITAcc);
+  else if (accry==11)
+    accmeasure = sqrt(mean(ITAcc));
+  else if (accry==12)
+    accmeasure = 1.0;
+  else if (accry==13)
+    accmeasure = 1.0 * (mean(ITsmape) + mean(ITAcc)) / 2;
+  else if (accry==15)
+    accmeasure = ITAcc.size() * log(sum(ITAcc));
+  else if (accry==16)
+    accmeasure = var(ITErr);
+  else
+    accmeasure = NA_REAL;
+  return accmeasure;
 }
 
 // [[Rcpp::export]]
@@ -162,8 +172,8 @@ double NaiveSD_Accry_hin(NumericVector train_set, double frqx, int accry, int h)
   fn = frqx - 1;
   for(j = 0; j < n; j++){
     if(fn < j)
-        fitsn[j] = train_set[j - frqx];
-    }
+      fitsn[j] = train_set[j - frqx];
+  }
   ITErr = train_set - fitsn;
   pe = (ITErr / fitsn) * 100.0;
   ITsmape = (abs(ITErr) / (abs(train_set) + abs(fitsn))) * 200.0;
@@ -219,50 +229,50 @@ double NaiveSV_Accry_hin(NumericVector train_set, NumericVector frqx, int accry,
   NumericVector hITErr(h);
   NumericVector hITsmape(h);
   deseas = train_set;
-      for(z = 0; z < p; z++){
-        fn = frqx[z] - 1;
-        for(j = 0; j < n; j++){
-          if(fn < j)
-            fitsn[j] = deseas[j - frqx[z]];
-          tfitsn[j] = tfitsn[j] + fitsn[j];
-        }
-        deseas = deseas - fitsn;
-      }
-    ITErr = train_set - tfitsn;
-    pe = (ITErr / tfitsn) * 100.0;
-    ITsmape = (abs(ITErr) / (abs(train_set) + abs(tfitsn))) * 200.0;
-    if ((accry==1) | (accry==2) | (accry==12) | (accry==13))
-      ITAcc = abs(ITErr);
-    else if ((accry==3) | (accry==4) | (accry==11) | (accry==15))
-      ITAcc = pow(ITErr, 2.0);
-    else if ((accry==5) | (accry==6) )
-      ITAcc = pe;
-    else if ((accry==7) | (accry==8) )
-      ITAcc = abs(pe);
-    else if ((accry==9) | (accry==10) )
-      ITAcc = ITsmape;
-    else
-      NumericVector ITAcc(n-1,NumericVector::get_na());
-    hITAcc = head(ITAcc, (n - h));
-    hITErr = head(ITErr, (n - h));
-    hITsmape = head(ITsmape, (n - h));
-    if ((accry==1) | (accry==3) | (accry==5) | (accry==7) | (accry==9) )
-      accmeasure = mean(hITAcc);
-    else if ((accry==2) | (accry==4) | (accry==6) | (accry==8) | (accry==10) )
-      accmeasure = median(hITAcc);
-    else if (accry==11)
-      accmeasure = sqrt(mean(hITAcc));
-    else if (accry==12)
-      accmeasure = 1.0;
-    else if (accry==13)
-      accmeasure = 1.0 * (mean(hITsmape) + mean(hITAcc)) / 2;
-    else if (accry==15)
-      accmeasure = hITAcc.size() * log(sum(hITAcc));
-    else if (accry==16)
-      accmeasure = var(hITErr);
-    else
-      accmeasure = NA_REAL;
-    return accmeasure;
+  for(z = 0; z < p; z++){
+    fn = frqx[z] - 1;
+    for(j = 0; j < n; j++){
+      if(fn < j)
+        fitsn[j] = deseas[j - frqx[z]];
+      tfitsn[j] = tfitsn[j] + fitsn[j];
+    }
+    deseas = deseas - fitsn;
+  }
+  ITErr = train_set - tfitsn;
+  pe = (ITErr / tfitsn) * 100.0;
+  ITsmape = (abs(ITErr) / (abs(train_set) + abs(tfitsn))) * 200.0;
+  if ((accry==1) | (accry==2) | (accry==12) | (accry==13))
+    ITAcc = abs(ITErr);
+  else if ((accry==3) | (accry==4) | (accry==11) | (accry==15))
+    ITAcc = pow(ITErr, 2.0);
+  else if ((accry==5) | (accry==6) )
+    ITAcc = pe;
+  else if ((accry==7) | (accry==8) )
+    ITAcc = abs(pe);
+  else if ((accry==9) | (accry==10) )
+    ITAcc = ITsmape;
+  else
+    NumericVector ITAcc(n-1,NumericVector::get_na());
+  hITAcc = head(ITAcc, (n - h));
+  hITErr = head(ITErr, (n - h));
+  hITsmape = head(ITsmape, (n - h));
+  if ((accry==1) | (accry==3) | (accry==5) | (accry==7) | (accry==9) )
+    accmeasure = mean(hITAcc);
+  else if ((accry==2) | (accry==4) | (accry==6) | (accry==8) | (accry==10) )
+    accmeasure = median(hITAcc);
+  else if (accry==11)
+    accmeasure = sqrt(mean(hITAcc));
+  else if (accry==12)
+    accmeasure = 1.0;
+  else if (accry==13)
+    accmeasure = 1.0 * (mean(hITsmape) + mean(hITAcc)) / 2;
+  else if (accry==15)
+    accmeasure = hITAcc.size() * log(sum(hITAcc));
+  else if (accry==16)
+    accmeasure = var(hITErr);
+  else
+    accmeasure = NA_REAL;
+  return accmeasure;
 }
 
 // [[Rcpp::export]]
@@ -296,14 +306,24 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
     }
     else
     {
-      if (IZIL==1)
+      if ((IZIL==1) & (i<=IZP))
       {
         Xlag = meanIT(IAZ,indx-1);
         Xobs = meanIT(IAZ,indx);
       }
+      else if ((IZIL==2) & (i<=IZP))
+      {
+        Xlag = medianIT(IAZ,indx-1);
+        Xobs = medianIT(IAZ,indx);
+      }
       else
       {
-        Xlag = IAZ[indx-1];
+        if ((IZIL==1) & (indx<=IZP))
+          Xlag = meanIT(IAZ,indx-1);
+        else if ((IZIL==2) & (indx<=IZP))
+          Xlag = medianIT(IAZ,indx-1);
+        else
+          Xlag = IAZ[indx-1];
         Xobs = IAZ[indx];
       }
     }
@@ -353,19 +373,19 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
           phiTotal = IZPHI;
           for(h = 1; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                phiTotal += pow(IZPHI, (h+1));
-                FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
+              phiTotal += pow(IZPHI, (h+1));
+              FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
         if (IZAC==17) {
           for(h = 0; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
+              FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
@@ -376,6 +396,8 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -386,19 +408,19 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
           phiTotal = IZPHI;
           for(h = 1; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                phiTotal += pow(IZPHI, (h+1));
-                FC(i,h) = pow(IAZ[i+h] - (S + (phiTotal * T)),2);
+              phiTotal += pow(IZPHI, (h+1));
+              FC(i,h) = pow(IAZ[i+h] - (S + (phiTotal * T)),2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
         if (IZAC==17) {
           for(h = 0; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
+              FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
@@ -407,6 +429,8 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -417,19 +441,19 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
           phiTotal = IZPHI;
           for(h = 1; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                phiTotal += pow(IZPHI, (h+1));
-                FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
+              phiTotal += pow(IZPHI, (h+1));
+              FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
         if (IZAC==17) {
           for(h = 0; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
+              FC(i,h) = pow(IAZ[i+h] - IZFIT[i],2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
@@ -448,10 +472,10 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
           phiTotal = IZPHI;
           for(h = 1; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                phiTotal += pow(IZPHI, (h+1));
-                FC(i,h) = pow(IAZ[i+h] - (S + (phiTotal * T)),2);
+              phiTotal += pow(IZPHI, (h+1));
+              FC(i,h) = pow(IAZ[i+h] - (S + (phiTotal * T)),2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
@@ -477,10 +501,10 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
           phiTotal = IZPHI;
           for(h = 1; h < IZNMSE; h++) {
             if((i+h) < LENZ){
-                phiTotal += pow(IZPHI, (h+1));
-                FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
+              phiTotal += pow(IZPHI, (h+1));
+              FC(i,h) = pow(IAZ[i+h] - (S * pow(T, phiTotal)),2);
             }else{
-                FC(i,h) = NA_REAL;
+              FC(i,h) = NA_REAL;
             }
           }
         }
@@ -496,12 +520,13 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
       }
     }
     else if ( (i>IZP) & (i<=IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -534,6 +559,8 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
         S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -563,7 +590,6 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
       }
     }
     else if ( (i>IZP) & (i>IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         coefqk = 1.0 * IZQ / i;
@@ -662,10 +688,10 @@ double SubATACore(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, i
       accmeasure = mean(ITAcc) / NaiveSD_Accry(IAZ, IZFRQ[0], 1);
   }
   else if (IZAC==13){
-      if(f > 1)
-        accmeasure = 1.0 * ((mean(ITsmape) / NaiveSV_Accry(IAZ, IZFRQ, 9)) + (mean(ITAcc) / NaiveSV_Accry(IAZ, IZFRQ, 1))) / 2;
-      else
-        accmeasure = 1.0 * ((mean(ITsmape) / NaiveSD_Accry(IAZ, IZFRQ[0], 9)) + (mean(ITAcc) / NaiveSD_Accry(IAZ, IZFRQ[0], 1))) / 2;
+    if(f > 1)
+      accmeasure = 1.0 * ((mean(ITsmape) / NaiveSV_Accry(IAZ, IZFRQ, 9)) + (mean(ITAcc) / NaiveSV_Accry(IAZ, IZFRQ, 1))) / 2;
+    else
+      accmeasure = 1.0 * ((mean(ITsmape) / NaiveSD_Accry(IAZ, IZFRQ[0], 9)) + (mean(ITAcc) / NaiveSD_Accry(IAZ, IZFRQ[0], 1))) / 2;
   }
   else if ((IZAC==14) | (IZAC==17))
     accmeasure = calc_amse(FC);
@@ -903,7 +929,7 @@ NumericVector SubATA(arma::mat IAX, int IXP, int IXQ, int IXMO, int IXAC, int IX
 
 
 // [[Rcpp::export]]
-double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, int IZAC, int IZIL, int IZIT, NumericVector IZTA_0, NumericVector IZTM_0, NumericVector IZFRQ, NumericVector IAZout) {
+double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, int IZAC, int IZIL, int IZIT, NumericVector IZTA_0, NumericVector IZTM_0, NumericVector IZFRQ, NumericVector IAZout, int onestep) {
   int LENZ = IAZ.size();
   int LENH = IAZout.size();
   int f = IZFRQ.length();
@@ -916,6 +942,10 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
   NumericVector peOUT(LENH);
   NumericVector ITsmapeOUT(LENH);
   NumericVector ITAccOUT(LENH);
+  NumericVector IAZonestep(LENZ+LENH);
+  IAZonestep[Range(0,LENZ-1)] = IAZ;
+  IAZonestep[Range(LENZ, LENZ+LENH-1)] = IAZout;
+
   double accmeasureOUT = 0;
 
   if (IZMO==1)
@@ -933,14 +963,24 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
     }
     else
     {
-      if (IZIL==1)
+      if ((IZIL==1) & (i<=IZP))
       {
         Xlag = meanIT(IAZ,indx-1);
         Xobs = meanIT(IAZ,indx);
       }
+      else if ((IZIL==2) & (i<=IZP))
+      {
+        Xlag = medianIT(IAZ,indx-1);
+        Xobs = medianIT(IAZ,indx);
+      }
       else
       {
-        Xlag = IAZ[indx-1];
+        if ((IZIL==1) & (indx<=IZP))
+          Xlag = meanIT(IAZ,indx-1);
+        else if ((IZIL==2) & (indx<=IZP))
+          Xlag = medianIT(IAZ,indx-1);
+        else
+          Xlag = IAZ[indx-1];
         Xobs = IAZ[indx];
       }
     }
@@ -971,6 +1011,8 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -981,6 +1023,8 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1007,12 +1051,13 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       }
     }
     else if ( (i>IZP) & (i<=IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -1024,6 +1069,8 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1032,7 +1079,6 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       }
     }
     else if ( (i>IZP) & (i>IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         coefqk = 1.0 * IZQ / i;
@@ -1059,35 +1105,55 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
     }
   }
 
-  if (IZIL==1)
-    Xobs = meanIT(IAZ,LENZ-1);
-  else
+  if (onestep==0){
     Xobs = IAZ[LENZ-1];
+    if (IZMO==1) {
+      coefpk = 1.0 * IZP / LENZ;
+      coefqk = 1.0 * IZQ / LENZ;
+      S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
+      T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
+      IZFRCST[0] = S + (IZPHI * T);
+      phiTotal = IZPHI;
+      for(h = 1; h < LENH; h++) {
+        phiTotal += pow(IZPHI, h);
+        IZFRCST[h] = S + (phiTotal * T);
+      }
+    }
+    if (IZMO==2) {
+      coefpk = 1.0 * IZP / LENZ;
+      coefqk = 1.0 * IZQ / LENZ;
+      S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
+      T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
+      IZFRCST[0] = S * pow(T, IZPHI);
+      phiTotal = IZPHI;
+      for(h = 1; h < LENH; h++) {
+        phiTotal += pow(IZPHI, h);
+        IZFRCST[h] = S * pow(T, phiTotal);
+      }
+    }
+  }
+  else{
+    h = 0;
+    for(indx = LENZ-1; indx < LENZ+LENH-1; indx++) {
+      Xobs = IAZonestep[indx];
+      if (IZMO==1) {
+        coefpk = 1.0 * IZP / (indx+1);
+        coefqk = 1.0 * IZQ / (indx+1);
+        S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
+        T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
+        IZFRCST[h] = S + (IZPHI * T);
+      }
+      if (IZMO==2) {
+        coefpk = 1.0 * IZP / (indx+1);
+        coefqk = 1.0 * IZQ / (indx+1);
+        S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
+        T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
+        IZFRCST[h] = S * pow(T, IZPHI);
+      }
+      h = h + 1;
+    }
+  }
 
-  if (IZMO==1) {
-    coefpk = 1.0 * IZP / LENZ;
-    coefqk = 1.0 * IZQ / LENZ;
-    S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
-    T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
-    IZFRCST[0] = S + (IZPHI * T);
-    phiTotal = IZPHI;
-    for(h = 1; h < LENH; h++) {
-      phiTotal += pow(IZPHI, h);
-      IZFRCST[h] = S + (phiTotal * T);
-    }
-  }
-  if (IZMO==2) {
-    coefpk = 1.0 * IZP / LENZ;
-    coefqk = 1.0 * IZQ / LENZ;
-    S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
-    T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
-    IZFRCST[0] = S * pow(T, IZPHI);
-    phiTotal = IZPHI;
-    for(h = 1; h < LENH; h++) {
-      phiTotal += pow(IZPHI, h);
-      IZFRCST[h] = S * pow(T, phiTotal);
-    }
-  }
   ITFrcstErr = IAZout - IZFRCST;
   peOUT = (ITFrcstErr / IAZout) * 100.0;
   ITsmapeOUT = (abs(ITFrcstErr) / (abs(IZFRCST) + abs(IAZout))) * 200.0;
@@ -1116,10 +1182,10 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       accmeasureOUT = mean(ITAccOUT) / NaiveSD_Accry(IAZ, IZFRQ[0], 1);
   }
   else if (IZAC==13){
-      if(f > 1)
-        accmeasureOUT = 1.0 * ((mean(ITsmapeOUT) / NaiveSV_Accry(IAZ, IZFRQ, 9)) + (mean(ITAccOUT) / NaiveSV_Accry(IAZ, IZFRQ, 1))) / 2;
-      else
-        accmeasureOUT = 1.0 * ((mean(ITsmapeOUT) / NaiveSD_Accry(IAZ, IZFRQ[0], 9)) + (mean(ITAccOUT) / NaiveSD_Accry(IAZ, IZFRQ[0], 1))) / 2;
+    if(f > 1)
+      accmeasureOUT = 1.0 * ((mean(ITsmapeOUT) / NaiveSV_Accry(IAZ, IZFRQ, 9)) + (mean(ITAccOUT) / NaiveSV_Accry(IAZ, IZFRQ, 1))) / 2;
+    else
+      accmeasureOUT = 1.0 * ((mean(ITsmapeOUT) / NaiveSD_Accry(IAZ, IZFRQ[0], 9)) + (mean(ITAccOUT) / NaiveSD_Accry(IAZ, IZFRQ[0], 1))) / 2;
   }
   else if (IZAC==15)
     accmeasureOUT = ITAccOUT.size() * log(sum(ITAccOUT));
@@ -1131,7 +1197,7 @@ double SubATACoreHoldout(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
 }
 
 // [[Rcpp::export]]
-NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO, int IXAC, int IXLF, int IXTF, int IXTS, double IXPHIS, double IXPHIE, double IXPHISS, int IXIL, int IXIT, NumericVector IXTA_0, NumericVector IXTM_0, NumericVector IXFRQ, NumericVector IAXout){
+NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO, int IXAC, int IXLF, int IXTF, int IXTS, double IXPHIS, double IXPHIE, double IXPHISS, int IXIL, int IXIT, NumericVector IXTA_0, NumericVector IXTM_0, NumericVector IXFRQ, NumericVector IAXout, int onestep){
   int LENX = IAX.size();
   int  	d_opt_p;
   int  	d_opt_q;
@@ -1165,7 +1231,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
     for(m = mstart; m <= mfinish; m++) {
       for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
         for(i = 1; i <= LENX; i++) {
-          optAccryEnd = SubATACoreHoldout(IAX, i, 0, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+          optAccryEnd = SubATACoreHoldout(IAX, i, 0, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
           if (optAccryEnd <= optAccryStart) {
             d_opt_phi = 1.0 * k;
             d_opt_p = i;
@@ -1175,7 +1241,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
           }
         }
         for(j = 0; j <= d_opt_p; j++) {
-          optAccryEnd = SubATACoreHoldout(IAX, d_opt_p, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+          optAccryEnd = SubATACoreHoldout(IAX, d_opt_p, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
           if (optAccryEnd <= optAccryStart) {
             d_opt_phi = 1.0 * k;
             d_opt_q = j;
@@ -1192,7 +1258,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
     for(m = mstart; m <= mfinish; m++) {
       for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
         for(i = 1; i <= LENX; i++) {
-          optAccryEnd = SubATACoreHoldout(IAX, i, 1, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+          optAccryEnd = SubATACoreHoldout(IAX, i, 1, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
           if (optAccryEnd <= optAccryStart) {
             d_opt_phi = 1.0 * k;
             d_opt_p = i;
@@ -1211,7 +1277,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
       for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
         for(j = 1; j <= LENX; j++) {
           for(i=1; ((j<=i) & (i<=LENX)); i++) {
-            optAccryEnd = SubATACoreHoldout(IAX,i, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+            optAccryEnd = SubATACoreHoldout(IAX,i, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
             if (optAccryEnd <= optAccryStart) {
               d_opt_phi = 1.0 * k;
               d_opt_p = i;
@@ -1231,7 +1297,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
         for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
           for(i = 1; i <= LENX; i++) {
             for(j=0; j<=i; j++) {
-              optAccryEnd = SubATACoreHoldout(IAX,i, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+              optAccryEnd = SubATACoreHoldout(IAX,i, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
               if (optAccryEnd <= optAccryStart) {
                 d_opt_phi = 1.0 * k;
                 d_opt_p = i;
@@ -1250,7 +1316,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
       for(m = mstart; m <= mfinish; m++) {
         for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
           for(i = 1; i <= LENX; i++) {
-            optAccryEnd = SubATACoreHoldout(IAX, i, IXQ, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+            optAccryEnd = SubATACoreHoldout(IAX, i, IXQ, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
             if (optAccryEnd <= optAccryStart) {
               d_opt_phi = 1.0 * k;
               d_opt_p = i;
@@ -1267,7 +1333,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
       for(m = mstart; m <= mfinish; m++) {
         for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
           for(j = 0; j <= IXP; j++) {
-            optAccryEnd = SubATACoreHoldout(IAX, IXP, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+            optAccryEnd = SubATACoreHoldout(IAX, IXP, j, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
             if (optAccryEnd <= optAccryStart) {
               d_opt_phi = 1.0 * k;
               d_opt_q = j;
@@ -1283,7 +1349,7 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
       d_opt_p = IXP;
       for(m = mstart; m <= mfinish; m++) {
         for(k = IXPHIS; k < IXPHIE+IXPHISS; k = k+IXPHISS) {
-          optAccryEnd = SubATACoreHoldout(IAX, IXP, IXQ, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout);
+          optAccryEnd = SubATACoreHoldout(IAX, IXP, IXQ, k, m, IXAC, IXIL, IXIT, IXTA_0, IXTM_0, IXFRQ, IAXout, onestep);
           if (optAccryEnd <= optAccryStart) {
             d_opt_phi = 1.0 * k;
             IXMO = m;
@@ -1303,7 +1369,9 @@ NumericVector SubATADampedHoldout(NumericVector IAX, int IXP, int IXQ, int IXMO,
 
 
 // [[Rcpp::export]]
-NumericVector SubATAHoldout(arma::mat IAX, int IXP, int IXQ, int IXMO, int IXAC, int IXLF, int IXTF, int IXTS, double IXPHIS, double IXPHIE, double IXPHISS, int IXIL, int IXIT, arma::mat IXTA_0, arma::mat IXTM_0, NumericVector IXSMO, NumericVector IXST, int max_smo, int max_st, NumericVector IXFRQ, NumericVector IAXout){
+NumericVector SubATAHoldout(arma::mat IAX, int IXP, int IXQ, int IXMO, int IXAC, int IXLF, int IXTF, int IXTS, double IXPHIS, double IXPHIE, double IXPHISS,
+                            int IXIL, int IXIT, arma::mat IXTA_0, arma::mat IXTM_0, NumericVector IXSMO, NumericVector IXST, int max_smo, int max_st,
+                            NumericVector IXFRQ, arma::mat IAXout, int onestep){
   int  d_opt_p;
   int  d_opt_q;
   double  d_opt_phi;
@@ -1327,10 +1395,11 @@ NumericVector SubATAHoldout(arma::mat IAX, int IXP, int IXQ, int IXMO, int IXAC,
       LastIXST = IXST[st-1];
       mod_clmn = (sm*max_st)-(st%max_st);
       NumericVector subIAX = wrap(IAX.col(mod_clmn-1));
+      NumericVector subIAXout = wrap(IAXout.col(mod_clmn-1));
       NumericVector subIXTA_0 = wrap(IXTA_0.col(mod_clmn-1));
       NumericVector subIXTM_0 = wrap(IXTM_0.col(mod_clmn-1));
-      output = SubATADampedHoldout(subIAX, IXP, IXQ, IXMO, IXAC, IXLF, IXTF, IXTS, IXPHIS, IXPHIE, IXPHISS, IXIL, IXIT, subIXTA_0, subIXTM_0, IXFRQ, IAXout);
-      optAccryEnd = SubATACoreHoldout(subIAX, output[0], output[1], output[2], output[3], IXAC, IXIL, IXIT, subIXTA_0, subIXTM_0, IXFRQ, IAXout);
+      output = SubATADampedHoldout(subIAX, IXP, IXQ, IXMO, IXAC, IXLF, IXTF, IXTS, IXPHIS, IXPHIE, IXPHISS, IXIL, IXIT, subIXTA_0, subIXTM_0, IXFRQ, subIAXout, onestep);
+      optAccryEnd = SubATACoreHoldout(subIAX, output[0], output[1], output[2], output[3], IXAC, IXIL, IXIT, subIXTA_0, subIXTM_0, IXFRQ, subIAXout, onestep);
       if (optAccryEnd <= optAccryStart){
         d_opt_p = output[0];
         d_opt_q = output[1];
@@ -1356,13 +1425,17 @@ NumericVector SubATAHoldout(arma::mat IAX, int IXP, int IXQ, int IXMO, int IXAC,
 
 
 // [[Rcpp::export]]
-NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, int IZIL, int IZIT, NumericVector IZTA_0, NumericVector IZTM_0, NumericVector IZFRQ, int LENH) {
+NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int IZMO, int IZIL, int IZIT, NumericVector IZTA_0, NumericVector IZTM_0, NumericVector IZFRQ, NumericVector IAZout, int onestep) {
   int LENZ = IAZ.size();
+  int LENH = IAZout.size();
   NumericVector IZT_0(LENZ);
   NumericVector IZFIT(LENZ);
   double coefpk, coefqk, Xobs, Xlag, phiTotal, S, T, S_1, T_1, T_0;
   int i, indx, h;
   NumericVector IZFRCST(LENH);
+  NumericVector IAZonestep(LENZ+LENH);
+  IAZonestep[Range(0,LENZ-1)] = IAZ;
+  IAZonestep[Range(LENZ, LENZ+LENH-1)] = IAZout;
 
   if (IZMO==1)
     IZT_0 = IZTA_0;
@@ -1379,14 +1452,24 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
     }
     else
     {
-      if (IZIL==1)
+      if ((IZIL==1) & (i<=IZP))
       {
         Xlag = meanIT(IAZ,indx-1);
         Xobs = meanIT(IAZ,indx);
       }
+      else if ((IZIL==2) & (i<=IZP))
+      {
+        Xlag = medianIT(IAZ,indx-1);
+        Xobs = medianIT(IAZ,indx);
+      }
       else
       {
-        Xlag = IAZ[indx-1];
+        if ((IZIL==1) & (indx<=IZP))
+          Xlag = meanIT(IAZ,indx-1);
+        else if ((IZIL==2) & (indx<=IZP))
+          Xlag = medianIT(IAZ,indx-1);
+        else
+          Xlag = IAZ[indx-1];
         Xobs = IAZ[indx];
       }
     }
@@ -1417,6 +1500,8 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -1427,6 +1512,8 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1453,12 +1540,13 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
       }
     }
     else if ( (i>IZP) & (i<=IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -1470,6 +1558,8 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
         S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1478,7 +1568,6 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
       }
     }
     else if ( (i>IZP) & (i>IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         coefqk = 1.0 * IZQ / i;
@@ -1504,32 +1593,53 @@ NumericVector ATAHoldoutForecast(NumericVector IAZ, int IZP, int IZQ, double IZP
       T_1 = NA_REAL;
     }
   }
-  if (IZIL==1)
-    Xobs = meanIT(IAZ,LENZ-1);
-  else
+
+  if (onestep==0){
     Xobs = IAZ[LENZ-1];
-  if (IZMO==1) {
-    coefpk = 1.0 * IZP / LENZ;
-    coefqk = 1.0 * IZQ / LENZ;
-    S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
-    T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
-    IZFRCST[0] = S + (IZPHI * T);
-    phiTotal = IZPHI;
-    for(h = 1; h < LENH; h++) {
-      phiTotal += pow(IZPHI, h);
-      IZFRCST[h] = S + (phiTotal * T);
+    if (IZMO==1) {
+      coefpk = 1.0 * IZP / LENZ;
+      coefqk = 1.0 * IZQ / LENZ;
+      S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
+      T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
+      IZFRCST[0] = S + (IZPHI * T);
+      phiTotal = IZPHI;
+      for(h = 1; h < LENH; h++) {
+        phiTotal += pow(IZPHI, h);
+        IZFRCST[h] = S + (phiTotal * T);
+      }
+    }
+    if (IZMO==2) {
+      coefpk = 1.0 * IZP / LENZ;
+      coefqk = 1.0 * IZQ / LENZ;
+      S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
+      T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
+      IZFRCST[0] = S * pow(T, IZPHI);
+      phiTotal = IZPHI;
+      for(h = 1; h < LENH; h++) {
+        phiTotal += pow(IZPHI, h);
+        IZFRCST[h] = S * pow(T, phiTotal);
+      }
     }
   }
-  if (IZMO==2) {
-    coefpk = 1.0 * IZP / LENZ;
-    coefqk = 1.0 * IZQ / LENZ;
-    S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
-    T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
-    IZFRCST[0] = S * pow(T, IZPHI);
-    phiTotal = IZPHI;
-    for(h = 1; h < LENH; h++) {
-      phiTotal += pow(IZPHI, h);
-      IZFRCST[h] = S * pow(T, phiTotal);
+  else{
+    h = 0;
+    for(indx = LENZ-1; indx < LENZ+LENH-1; indx++) {
+      Xobs = IAZonestep[indx];
+      if (IZMO==1) {
+        coefpk = 1.0 * IZP / (indx+1);
+        coefqk = 1.0 * IZQ / (indx+1);
+        S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
+        T = coefqk * (S - S_1) + (1-coefqk) * (IZPHI * T_1);
+        IZFRCST[h] = S + (IZPHI * T);
+      }
+      if (IZMO==2) {
+        coefpk = 1.0 * IZP / (indx+1);
+        coefqk = 1.0 * IZQ / (indx+1);
+        S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
+        T = coefqk * (1.0 * S / S_1) + (1-coefqk) * pow(T_1, IZPHI);
+        IZFRCST[h] = S * pow(T, IZPHI);
+      }
+      h = h + 1;
     }
   }
   return IZFRCST;
@@ -1550,11 +1660,11 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
   double phiTotal=0.0;
   NumericVector pe(LENZ);
   NumericVector ITsmape(LENZ);
+  NumericMatrix FC(LENZ, IZNMSE);
   NumericVector hITAcc(IZH);
   NumericVector hITErr(IZH);
   NumericVector hITsmape(IZH);
-  NumericVector hFC(IZH);
-  NumericMatrix FC(LENZ, IZNMSE);
+  NumericMatrix hFC(IZH, IZNMSE);
 
   if (IZMO==1)
     IZT_0 = IZTA_0;
@@ -1571,14 +1681,24 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
     }
     else
     {
-      if (IZIL==1)
+      if ((IZIL==1) & (i<=IZP))
       {
         Xlag = meanIT(IAZ,indx-1);
         Xobs = meanIT(IAZ,indx);
       }
+      else if ((IZIL==2) & (i<=IZP))
+      {
+        Xlag = medianIT(IAZ,indx-1);
+        Xobs = medianIT(IAZ,indx);
+      }
       else
       {
-        Xlag = IAZ[indx-1];
+        if ((IZIL==1) & (indx<=IZP))
+          Xlag = meanIT(IAZ,indx-1);
+        else if ((IZIL==2) & (indx<=IZP))
+          Xlag = medianIT(IAZ,indx-1);
+        else
+          Xlag = IAZ[indx-1];
         Xobs = IAZ[indx];
       }
     }
@@ -1651,6 +1771,8 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -1682,6 +1804,8 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = 1.0 * Xobs;
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1771,12 +1895,13 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       }
     }
     else if ( (i>IZP) & (i<=IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         S = coefpk * Xobs + (1-coefpk) * (S_1 + (IZPHI * T_1));
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S + (IZPHI * T);
@@ -1809,6 +1934,8 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
         S = coefpk * Xobs + (1-coefpk) * S_1 * pow(T_1, IZPHI);
         if (IZIT==1)
           T = meanIT(IZT_0,indx);
+        else if (IZIT==2)
+          T = medianIT(IZT_0,indx);
         else
           T = T_0;
         IZFIT[i] = S * pow(T, IZPHI);
@@ -1838,7 +1965,6 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       }
     }
     else if ( (i>IZP) & (i>IZQ) & (IZP>=IZQ) ) {
-      Xobs = IAZ[indx];
       if (IZMO==1) {
         coefpk = 1.0 * IZP / i;
         coefqk = 1.0 * IZQ / i;
@@ -1939,13 +2065,15 @@ double SubATACoreHoldhin(NumericVector IAZ, int IZP, int IZQ, double IZPHI, int
       accmeasure = mean(hITAcc) / NaiveSD_Accry_hin(IAZ, IZFRQ[0], 1, IZH);
   }
   else if (IZAC==13){
-      if(f > 1)
-        accmeasure = 1.0 * ((mean(hITsmape) / NaiveSV_Accry_hin(IAZ, IZFRQ, 9, IZH)) + (mean(hITAcc) / NaiveSV_Accry_hin(IAZ, IZFRQ, 1, IZH))) / 2;
-      else
-        accmeasure = 1.0 * ((mean(hITsmape) / NaiveSD_Accry_hin(IAZ, IZFRQ[0], 9, IZH)) + (mean(hITAcc) / NaiveSD_Accry_hin(IAZ, IZFRQ[0], 1, IZH))) / 2;
+    if(f > 1)
+      accmeasure = 1.0 * ((mean(hITsmape) / NaiveSV_Accry_hin(IAZ, IZFRQ, 9, IZH)) + (mean(hITAcc) / NaiveSV_Accry_hin(IAZ, IZFRQ, 1, IZH))) / 2;
+    else
+      accmeasure = 1.0 * ((mean(hITsmape) / NaiveSD_Accry_hin(IAZ, IZFRQ[0], 9, IZH)) + (mean(hITAcc) / NaiveSD_Accry_hin(IAZ, IZFRQ[0], 1, IZH))) / 2;
+  }
+  else if ((IZAC==14) | (IZAC==17)){
+    hFC = FC(Range(LENZ-IZH,LENZ-1), Range(0,IZNMSE-1));
+    accmeasure = calc_amse(hFC);
   }
-  else if ((IZAC==14) | (IZAC==17))
-      accmeasure = calc_amse(FC);
   else if (IZAC==15)
     accmeasure = hITAcc.size() * log(sum(hITAcc));
   else if (IZAC==16)
